Struct capctl::caps::FullCapState

source ·
#[non_exhaustive]
pub struct FullCapState { pub permitted: CapSet, pub effective: CapSet, pub inheritable: CapSet, pub ambient: CapSet, pub bounding: CapSet, pub no_new_privs: bool, }
Represents the “full” capability state of a thread (i.e. the contents of all 5 capability sets and some additional information).

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
permitted: CapSeteffective: CapSetinheritable: CapSetambient: CapSetbounding: CapSetno_new_privs: bool

Implementations

source

impl FullCapState

source

pub fn empty() -> Self

Construct an empty FullCapState object.

source

pub fn get_current() -> Result<Self>

Get the full capability state of the current thread.

This is equivalent to FullCapState::get_for_pid(0). However, this method uses the kernel APIs to retrieve information instead of examining files in /proc.

source

pub fn get_for_pid(pid: pid_t) -> Result<Self>

Get the full capability state of the process (or thread) with the given PID (or TID) by examining special files in /proc.

If pid is 0, this method gets the capability state of the current thread.