Interfaces to Linux capabilities.
Modules
Structs
An iterator over all the capabilities enumerated in Cap.
Represents a set of capabilities.
An iterator over all the capabilities in a CapSet.
Represents the permitted, effective, and inheritable capability sets of a thread.
Represents the capabilities attached to a file.
Represents the “full” capability state of a thread (i.e. the contents of all 5 capability sets and some additional information).
Represents an error when parsing a Cap from a string.
Represents an error when parsing a CapState object from a string.
Represents an error when parsing a FileCaps object from a string.
Enums
An enum representing all of the possible Linux capabilities.
Functions
Set the current thread’s UID/GID/supplementary groups while preserving permitted capabilities.